# django_deepl_po

Django_deepl_po is a module that allows you to translate Django project .po files using DeepL.

# Requirements

- Python 3.12+
- Django 3.2+

# Installation

- run `pip install django_deepl_po`
- add `django_deepl_po` to your `INSTALLED_APPS`
